import React from 'react';
import './App.css';
import {
  BrowserRouter as Router,
  Switch,
  Route,
} from "react-router-dom";
import Login from "./views/Login/Login";
import Register from "./views/Register/Register";
import Home from "./views/Home/Home";
import BusinessGrid from "./views/BusinessGrid/BusinessGrid";
import Navbar from './components/Navbar/Navbar';
import BusinessRegister from './views/BusinessRegister/BusinessRegister';
import { ProvideAuth } from './hooks/auth.js';
import { ProvideFilters } from './hooks/filter';
import PrivateRoute from './hooks/PrivateRoute';
import MyBusiness from './views/MyBusiness/MyBusiness';
import BusinessView from './views/BusinessDetails/BusinessView';
import { Wrapper } from '@googlemaps/react-wrapper';

function App() {

  var script = document.createElement('script');
  script.src = `https://maps.googleapis.com/maps/api/js?key=${process.env.REACT_APP_GOOGLE_MAPS_API_KEY}&libraries=localContext&callback=initMap`;
  script.async = true;

  // Attach your callback function to the `window` object
  window.initMap = function () {
    // JS API is loaded and available
  };

  // Append the 'script' element to 'head'
  document.head.appendChild(script);

  return (
    <ProvideAuth>
      <ProvideFilters>
        <Router>
          <Navbar />
          <Switch>
            <Route exact path="/login">
              <Login />
            </Route>
            <Route exact path="/register">
              <Register />
            </Route>
            <Route exact path="/businesses">
              <BusinessGrid />
            </Route>
            <Route path="/business/:businessId" children={<BusinessView />} />
            <PrivateRoute exact path="/mybusiness">
              <MyBusiness />
            </PrivateRoute>
            <PrivateRoute exact path="/businesses/register/1">
              <BusinessRegister status="creating" />
            </PrivateRoute>
            <PrivateRoute exact path="/businesses/register/2">
              <BusinessRegister status="missingImages" />
            </PrivateRoute>
            <Route path="/">
              <Home />
            </Route>
          </Switch>
        </Router>
      </ProvideFilters>
    </ProvideAuth>
  );
}

export default App;
