import React, { useEffect } from "react";
import { Flex, Link, Input, HStack, Text } from "@chakra-ui/react";
import Avatar from "../Avatar/Avatar";
import { useHistory, useLocation } from "react-router-dom";
import styles from "./navbar.module.css";
import Select from 'react-select';
import makeAnimated from 'react-select/animated';
import { useFilters } from "../../hooks/filter";
import { getCategories } from '../../helpers/categories/';

const Navbar = (avatar) => {
  const location = useLocation();
  const history = useHistory();
  const animatedComponents = makeAnimated();
  const { categories, filterCategories, setFilterCategories, filterText, handleTextSearch, setCategories } = useFilters();
  const filtersVisible = location.pathname === '/businesses';

  useEffect(() => {
    async function fetchData() {
      const serverCategories = await getCategories();
      serverCategories.forEach(category => {
        // eslint-disable-next-line
        delete Object.assign(category, { ['value']: category['id'] })['id'];
        // eslint-disable-next-line
        delete Object.assign(category, { ['label']: category['name'] })['name'];
      });
      setCategories(serverCategories);
      console.log(categories);
    }
    fetchData();
  }, []);

  return (
    <Flex
      align='center'
      p={2}
      minH="56px"
      className={styles.navbar}
      bgColor="white"
      boxShadow=""
      justifyContent='space-between'
    >
      <Link
        fontSize="lg"
        bgGradient="linear(to-l, #7928CA,#FF0080)"
        bgClip="text"
        fontWeight="extrabold"
        onClick={() => history.push('/')}
        mx={10}
      >
        Nearly
        </Link>
      <HStack >
        {filtersVisible && <Text>Filtres:</Text>}
        <div style={{ width: '400px' }}>
          {filtersVisible && <Select
            isMulti
            name="categories"
            options={categories}
            value={filterCategories}
            closeMenuOnSelect={false}
            components={animatedComponents}
            onChange={setFilterCategories}
            placeholder="Selecciona una o més categories"
          />}
        </div>
        <div style={{ width: '400px' }}>
          {filtersVisible && <Input placeholder="Escriu aquí per filtrar els resultats..." value={filterText} onChange={handleTextSearch} />}
        </div>
      </HStack>
      { avatar && <Avatar />}
    </Flex>
  )
};

export default Navbar;