import React, { useState, useEffect, useContext, createContext } from 'react'
import { api } from '../helpers/api';
import { getSessionUser, getAccessToken, removeUser, setSessionTokens, setSessionUser } from '../helpers/auth';

const authContext = createContext();

export function ProvideAuth({ children }) {
  const auth = useProvideAuth()
  return <authContext.Provider value={auth}> {children} </authContext.Provider>
}

export const useAuth = () => useContext(authContext);

const storageUser = getSessionUser() ? getSessionUser() : null;
const storageToken = getAccessToken() ? getAccessToken() : null;

function useProvideAuth() {
  const [user, setUser] = useState(storageUser);
  const [tokens, setTokens] = useState(storageToken);

  const register = async ({ name, email, password }) => {
    const { data } = await api.post("/auth/register", { name, email, password });
    setSessionTokens(data.tokens);
    setSessionUser(data.user);
    setUser(data.user);
    setTokens(data.tokens);
  };

  const login = async ({ email, password }) => {
    const { data } = await api.post("/auth/login", { email, password });
    setUser(data.user);

    setTokens(data.tokens);
    setSessionTokens(data.tokens);
    setSessionUser(data.user);
  };

  const logout = () => {
    setUser(null);
    setTokens(null);
    removeUser();
  };

  useEffect(() => {
    //check authentication
  }, [])
  return {
    user,
    tokens,
    register,
    login,
    logout,
  }
}