import { createContext, useContext, useState } from 'react';

const filtersContext = createContext();

export function ProvideFilters({ children }) {
  const filters = useProvideFilters();
  return <filtersContext.Provider value={filters}> {children} </filtersContext.Provider>
}

export const useFilters = () => useContext(filtersContext);

const useProvideFilters = () => {
  const [categories, setCategories] = useState([]);
  const [filterCategories, setFilterCategories] = useState([]);
  const [filterText, setFilterText] = useState('');

  const handleTextSearch = (e) => {
    setFilterText(e.target.value);
  }

  const categoryInFilter = (categoryId) => {
    if (filterCategories.length === 0) return true;
    return filterCategories.some(category => category.value === categoryId);
  };

  const categoryFilter = (business) => {
    return business.categories.some(category => categoryInFilter(category.id));
  }

  const textSearch = (business) => {
    if (filterText.length === 0) return true;
    return business.name.includes(filterText);
  }

  const isShown = (business) => {
    return textSearch(business) && categoryFilter(business);
  }

  return { categories, handleTextSearch, isShown, setFilterCategories, setCategories };
}