import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import { Flex, Box, Text, Link, HStack } from '@chakra-ui/react';
import { FaEnvelope, FaFacebook, FaTwitter, FaLinkedinIn, FaInstagram, FaPhone } from 'react-icons/fa';
import ImageBackground from './../../components/ImageBackground/ImageBackground';
import { getBusinessById } from '../../helpers/business';
import AwesomeSlider from 'react-awesome-slider';
import 'react-awesome-slider/dist/styles.css';

const BusinessView = () => {
  const { businessId } = useParams();
  const [business, setBusiness] = useState({});
  const [businessImages, setBuisinessImages] = useState([]);

  useEffect(() => {
    async function fetchData() {
      const business = await getBusinessById({ businessId });
      const { images: { gallery } } = business;
      const images = [];
      gallery.forEach((image) => {
        images.push({ source: image.url });
      });
      console.log(business);
      setBuisinessImages(images);
      setBusiness(business);
    }
    fetchData();
  }, []);

  const getBusinessFullAdress = (address) => {
    return `${address.street}, ${address.city}, ${address.postalCode}, ${address.province}, ${address.country}`
  }

  return (
    <div>
      <Flex
        minHeight='100vh'
        align='center'
        px={10}
      >

        <Box mr={10} p={5} minHeight={500} maxW={500} borderRadius="lg" boxShadow="5px 5px 29px -6px rgba(0, 0, 0, 0.21)" background="white">
          <Text fontSize="3xl">{business.name}</Text>
          {business.address && <Text as="i" fontSize="md">{getBusinessFullAdress(business.address)}</Text>}
          <HStack mt={2}>
            <FaEnvelope />
            {business.contactInfo && (
              <Link href={business.contactInfo.email} isExternal>
                {business.contactInfo.email}
              </Link>
            )}
            <FaPhone />
            {business.contactInfo && (
              <Link href={business.contactInfo.email} isExternal>
                {business.contactInfo.email}
              </Link>
            )}
          </HStack>
          <Text mt={5} fontSize="lg">{business.description}</Text>
          <HStack mt={5}>
            <FaInstagram />
            {business.contactInfo && (
              <Link href={business.contactInfo.instagram} isExternal>
                {business.contactInfo.instagram}
              </Link>
            )}
            <FaFacebook />
            {business.contactInfo && (
              <Link href={business.contactInfo.facebook} isExternal>
                {business.contactInfo.facebook}
              </Link>
            )}
          </HStack>
          <HStack mt={1}>
            <FaTwitter />
            {business.contactInfo && (
              <Link href={business.contactInfo.twitter} isExternal>
                {business.contactInfo.twitter}
              </Link>
            )}
            <FaLinkedinIn />
            {business.contactInfo && (
              <Link href={business.contactInfo.linkedIn} isExternal>
                {business.contactInfo.linkedIn}
              </Link>
            )}
          </HStack>
        </Box>
        <AwesomeSlider
          media={businessImages}
        />

      </Flex>
      <ImageBackground />
    </div>

  );
}

export default BusinessView;