import React, { useEffect, useState } from 'react';
import { getBusinesses } from '../../helpers/business/index';
import BusinessGridElement from './BusinessGridElement';
import Fade from 'react-reveal/Fade';
import { usePosition } from '../../hooks/position';
import businessDistance from '../../utils/distanceMatrix';
import ImageBackground from './../../components/ImageBackground/ImageBackground';
import { useFilters } from '../../hooks/filter';
import styles from './businessGrid.module.css';
import { useHistory } from 'react-router';

const getBusinessesArrays = (businesses) => {
  const array1 = [];
  const array2 = [];

  for (let i = 0; i < businesses.length; i++) {
    if (i % 2 === 0) array1.push(businesses[i]);
    else array2.push(businesses[i]);
  }

  return { array1, array2 }
};

const BusinessGrid = () => {
  const [businesses, setBusinesses] = useState({ array1: [], array2: [] });
  const { lat, lng } = usePosition();
  const { isShown } = useFilters();
  const history = useHistory();

  useEffect(() => {
    async function fetchData() {
      const allBusiness = await getBusinesses();
      if (lat && lng) {
        allBusiness.forEach(async business => {
          business.distance = await businessDistance({ bLat: business.address.location.coordinates[1], bLng: business.address.location.coordinates[0], lat, lng });
        });
      }
      setBusinesses(getBusinessesArrays(allBusiness));
    }
    fetchData();
  }, [lat, lng]);

  return (
    <div className={styles.flexContainer}>
      <div className={styles.flexLeft}>
        <Fade left cascade>
          <div>
            {businesses
              .array1
              .filter(business => isShown(business)).
              map(business => business.approved &&
                <BusinessGridElement
                  key={business.id}
                  business={business}
                />
              )}
          </div>
        </Fade>
      </div>
      <div className={styles.flexRight}>
        <Fade left cascade>
          <div>
            {businesses
              .array2
              .filter(business => isShown(business)).
              map(business => business.approved &&
                <BusinessGridElement
                  key={business.id}
                  business={business}
                />
              )}          </div>
        </Fade>
      </div>
      <ImageBackground />
    </div>
  )
}

export default BusinessGrid;