import { Flex, Box, Heading, Link } from '@chakra-ui/react';
import { StarIcon } from '@chakra-ui/icons';
import React, { useEffect, useState } from 'react';
import AwesomeSlider from 'react-awesome-slider';
import 'react-awesome-slider/dist/styles.css';
import { useHistory } from 'react-router';

const BusinessGridElement = ({ business }) => {
  const [businessImages, setBuisinessImages] = useState();
  const history = useHistory();
  
  const RenderCategories = ({ categories }) => {
    return (
      <div>
        {categories.map((category, index, array) => <div>{category.name} {index < array.length - 1 ? <div>&bull;</div> : ''} </div>)}
      </div>
    )
  };

  useEffect(() => {
    if (business.images) {
      const { images: { gallery } } = business;
      const images = [];
      gallery.forEach((image) => {
        images.push({ source: image.url });
      });
      setBuisinessImages(images);
    }
  }, [business]);

  const viewBusiness = (business) => {
    history.push(`/business/${business.id}`)
  }

  return (
    <Flex my={10}>
      <Box w={400} h={400} textAlign='left' borderRadius="lg" overflow="hidden" boxShadow="5px 5px 29px -6px rgba(0, 0, 0, 0.21)" background="white">
        <Box h={270}>
          <AwesomeSlider
            media={businessImages}
          />
        </Box>
        <Box mt={4} px={4}>
          <Box
            color="gray.500"
            fontWeight="semibold"
            letterSpacing="wide"
            fontSize="xs"
            textTransform="uppercase"
            ml="2"
          >
            <RenderCategories categories={business.categories} />
          </Box>
          <Heading as="h4" size="md" pt={1} px={2} isTruncated onClick={() => viewBusiness(business)}><Link>{business.name}</Link></Heading>
          <Box px={2} fontSize="sm">
            {3}
            <Box as="span" color="gray.600" fontSize="sm">
              &nbsp;km de tu
            </Box>
          </Box>
          <Box d="flex" px={2} alignItems="center">
            {Array(5)
              .fill("")
              .map((_, i) => (
                <StarIcon
                  key={business.rating}
                  color={business.rating > i + 1 ? "#7928CA" : "gray.300"}
                />
              ))}
            <Box as="span" ml="2" color="gray.600" fontSize="sm">
              puntuació de <a href={`https://www.google.com/maps/search/?api=1&query=Google&query_place_id=${business.address.placeId}`} target="_blanc">Google</a>
            </Box>
          </Box>
        </Box>
      </Box>
    </Flex>
  )
}

export default BusinessGridElement;
