import React, { useEffect, useState } from 'react';
import { FilePond, registerPlugin } from "react-filepond";
import { Box, Button, Heading, Text } from '@chakra-ui/react';
import "filepond/dist/filepond.min.css";
import FilePondPluginImageExifOrientation from "filepond-plugin-image-exif-orientation"
import FilePondPluginImagePreview from "filepond-plugin-image-preview"
import FilePondPluginFileValidateType from 'filepond-plugin-file-validate-type';

import "filepond-plugin-image-preview/dist/filepond-plugin-image-preview.css";
import { uploadImages } from '../../helpers/business';
import { useHistory, useLocation } from 'react-router-dom';
import { useAuth } from '../../hooks/auth';

registerPlugin(FilePondPluginImageExifOrientation, FilePondPluginImagePreview, FilePondPluginFileValidateType);

const UploadImages = () => {
  const { user } = useAuth();
  const history = useHistory();
  const location = useLocation();
  const [imgCollection, setImgCollection] = useState([])
  const [isLoading, setIsLoading] = useState(false);
  const [businessId, setBusinessId] = useState();

  useEffect(() => {
    if (location.state) {
      setBusinessId(location.state.businessId);
    }
    if (user.business) {
      if (!user.business || user.business.status === 'finished') {
        history.push('/mybusiness');
      }
      setBusinessId(user.business.id);
    }
  }, [location, user, history]);


  const onSubmit = async (e) => {

    e.preventDefault()
    setIsLoading(true);
    const files = imgCollection.map(fileItem => fileItem.file);

    const formData = new FormData()

    files.forEach(file => formData.append('file', file));

    const business = await uploadImages(businessId, formData).then(setIsLoading(false));
    if (business) {
      history.push('/mybusiness');
    }
  }



  return (
    <div>
      <Box my={8} alignItems="center">
        <Heading as="h3" size="lg">
          Afegeix imatges del teu negoci, productes, etc.
        </Heading>
        <Text mt={2}>
          La primera imatge serà la principal. Pots ordernar les imatges arrossegant amb el ratolí.
        </Text>
        <form onSubmit={onSubmit}>
          <Button
            bgGradient="linear(to-r, red.500, yellow.500)"
            color="white"
            _hover={{
              bgGradient: "linear(to-l, #7928CA,#FF0080)",
            }}
            width='full'
            mt={4}
            isLoading={isLoading}
            type="submit"
            w={200}
            isDisabled={imgCollection.length === 0}
          >
            Pujar Imatges
        </Button>
          <Box mt={8}>
            <FilePond
              files={imgCollection}
              allowMultiple={true}
              allowReorder={true}
              maxFiles={10}
              onupdatefiles={setImgCollection}
              acceptedFileTypes={['image/*']}
              labelIdle='Fes click <span class="filepond--label-action">aquí</span> o arrossega les imatges des de qualsevol directori.'
            >
            </FilePond>
          </Box>
        </form>
      </Box>
    </div >
  )
}

export default UploadImages;