import React, { useState } from "react";
import {
  Box,
  Link,
  FormControl,
  FormLabel,
  Input,
  Stack,
  Checkbox,
  Button, InputGroup, InputLeftElement, FormErrorMessage, InputRightElement,
} from '@chakra-ui/react';

import { useHistory } from "react-router-dom";
import { useAuth } from './../../hooks/auth';
import { Field, Form, Formik } from "formik";
import { FaEnvelope, FaEye, FaEyeSlash, FaKey } from 'react-icons/fa';

const LoginForm = () => {
  let history = useHistory();
  const [show, setShow] = useState(false);
  const auth = useAuth();
  const showPassword = () => setShow(!show);

  const validateEmail = (value) => {
    if (!value) {
      return "L'adreça es obligatòria.";
    }
  }

  const validatePassword = (value) => {
    if (!value) {
      return "La contrasenya es obligatòria"
    }
  }

  const submitLoginForm = (values, actions) => {
    auth.login({ email: values.email, password: values.password }).then((res) => {
      actions.setSubmitting(false);
      history.push("/");
    });
  };

  return (
    <Box my={8} textAlign='left'>
      <Formik
        initialValues={{ email: "", password: "" }}
        onSubmit={submitLoginForm}
      >
        {(props) => (
          <Form>
            <Field name="email" validate={validateEmail}>
              {({ field, form }) => (
                <FormControl isRequired isInvalid={form.errors.email} mt={2}>
                  <FormLabel>Adreça de correu</FormLabel>
                  <InputGroup>
                    <InputLeftElement
                      pointerEvents="none"
                      children={<FaEnvelope color="gray.300" />}
                    />
                    <Input {...field} id="email" type='email' placeholder='Adreça de correu' />
                  </InputGroup>
                  <FormErrorMessage>{form.errors.email}</FormErrorMessage>
                </FormControl>
              )}
            </Field>

            <Field name="password" validate={validatePassword}>
              {({ field, form }) => (
                <FormControl isRequired isInvalid={form.errors.password} mt={2}>
                  <FormLabel>Contrasenya</FormLabel>
                  <InputGroup>
                    <InputLeftElement
                      pointerEvents="none"
                      children={<FaKey color="gray.300" />}
                    />
                    <Input
                      pr="4.5rem"
                      type={show ? "text" : "password"}
                      placeholder="Contrasenya"
                      {...field}
                    />
                    <InputRightElement
                      width="4.5rem"
                      children={show ? <FaEyeSlash color="gray.300" /> : <FaEye color="gray.300" />}
                      onClick={showPassword}
                    />
                  </InputGroup>
                  <FormErrorMessage>{form.errors.password}</FormErrorMessage>
                </FormControl>
              )}
            </Field>
            <Stack isInline justifyContent='space-between' mt={4}>
              <Box>
                <Checkbox>Recorda'm</Checkbox>
              </Box>
              <Box>
                <Link colorScheme={'purple'}>Has oblidat la teva contrasenya?</Link>
              </Box>
            </Stack>
            <Button
              bgGradient="linear(to-l, #7928CA,#FF0080)"
              color="white"
              _hover={{
                bgGradient: "linear(to-r, red.500, yellow.500)",
              }}
              width='full'
              mt={4}
              isLoading={props.isSubmitting}
              type="submit"
            >
              Entrar
              </Button>
            <Box align="center" justifyContent='center' mt={4}>
              <Link onClick={() => history.push("/register")} colorScheme={'purple'}>No estàs registrat? Regisra't!</Link>
            </Box>
          </Form>
        )}
      </Formik>
    </Box>
  )
}

export default LoginForm;