import React, { useState, useEffect } from 'react';
import Select from 'react-select';
import makeAnimated from 'react-select/animated';
import { useHistory } from "react-router-dom";
import AwesomeSlider from 'react-awesome-slider';
import 'react-awesome-slider/dist/styles.css';

import {
  Box,
  FormControl,
  FormLabel,
  Input,
  InputLeftElement,
  InputGroup,
  Textarea,
  InputLeftAddon,
  HStack,
  Button,
  Heading,
} from '@chakra-ui/react';
import { FaEnvelope, FaFacebook, FaTwitter, FaLinkedinIn, FaInstagram } from 'react-icons/fa';
const availableDays = {
  "monday": "Dilluns",
  "tuesday": "Dimarts",
  "wednesday": "Dimecres",
  "thursday": "Dijous",
  "friday": "Divendres",
  "saturday": "Dissabte",
  "sunday": "Diumenge",
};

const BusinessDetails = ({ business }) => {
  const [categories, setCategories] = useState([]);
  const [days, setDays] = useState([]);
  const animatedComponents = makeAnimated();
  const [businessImages, setBuisinessImages] = useState([]);

  const history = useHistory();

  useEffect(() => {
    const { categories } = business;
    categories.forEach(category => {
      // eslint-disable-next-line
      delete Object.assign(category, { ['value']: category['id'] })['id'];
      // eslint-disable-next-line
      delete Object.assign(category, { ['label']: category['name'] })['name'];
    });
    const { timeTable: { days } } = business;
    const daysSelected = [];
    days.forEach(day => {
      daysSelected.push({ value: day, label: availableDays[day] });
    });

    if (business.images) {
      const { images: { gallery } } = business;
      const images = [];
      gallery.forEach((image) => {
        images.push({ source: image.url });
      });
      setBuisinessImages(images);
    }
    setDays(daysSelected);
    setCategories(categories);
  }, [business]);

  const handleClick = () => {
    history.push('/businesses/register/2', { businessId: business.id });
  }
  return (
    <div>
      <Box my={8} textAlign='left'>
        {!business.approved && <Heading
          as="h3"
          size="lg"
          style={{ color: 'gray' }}
          mt={2}
        >
          Negoci pendent d'aprovació
        </Heading>
        }
        <HStack mt={4}>
          <FormControl pr={8}>
            <FormLabel>Nom del negoci</FormLabel>
            <InputGroup>
              <Input value={business.name} isDisabled={true} type='text' />
            </InputGroup>
          </FormControl>
          <FormControl pl={8}>
            <FormLabel>Categories</FormLabel>
            <Select
              isDisabled={true}
              value={categories}
              isMulti
              closeMenuOnSelect={false}
              components={animatedComponents}
            />
          </FormControl>
        </HStack>
        <HStack mt={2}>
          <FormControl pr={8}>
            <FormLabel>Dies obert</FormLabel>
            <Select
              isDisabled={true}
              value={days}
              isMulti
              closeMenuOnSelect={false}
              components={animatedComponents}
            />
          </FormControl>
          <FormControl pl={8}>
            <FormLabel>Horari</FormLabel>
            <HStack textAlign="center" alignItems="center">
              <FormLabel>De</FormLabel>
              <Input isDisabled={true} value={business.timeTable.from} />
              <FormLabel>A</FormLabel>
              <Input isDisabled={true} value={business.timeTable.to} />
            </HStack>
          </FormControl>
        </HStack>
        <FormControl mt={2}>
          <FormLabel>Descripció del negoci</FormLabel>
          <Textarea
            isDisabled={true}
            value={business.description}
            h={150}
          />
        </FormControl>

        <FormControl mt={2}>
          <FormLabel>Direcció</FormLabel>
          <Input
            isDisabled={true}
            value={`${business.address.street}, ${business.address.city}, ${business.address.province}, ${business.address.country}`}
            type='text'
          />
        </FormControl>

        <HStack mt={2}>
          <FormControl pr={8}>
            <FormLabel>Adreça de correu del negoci</FormLabel>
            <InputGroup>
              <InputLeftElement
                pointerEvents="none"
                children={<FaEnvelope color="gray.300" />}
              />
              <Input isDisabled={true} value={business.contactInfo.email} type='email' />
            </InputGroup>
          </FormControl>

          <FormControl pl={8}>
            <FormLabel>Telefon de contacte</FormLabel>
            <InputGroup>
              <InputLeftAddon children="+34" />
              <Input isDisabled={true} value={business.contactInfo.phone} type='email' />
            </InputGroup>
          </FormControl>
        </HStack>
        <HStack mt={2}>
          <FormControl pr={8}>
            <FormLabel>Instagram</FormLabel>
            <InputGroup>
              <InputLeftElement
                pointerEvents="none"
                children={<FaInstagram color="gray.300" />}
              />
              <Input isDisabled={true} value={business.contactInfo.instagram} type='email' />
            </InputGroup>
          </FormControl>
          <FormControl pl={8}>
            <FormLabel>Facebook</FormLabel>
            <InputGroup>
              <InputLeftElement
                pointerEvents="none"
                children={<FaFacebook color="gray.300" />}
              />
              <Input isDisabled={true} value={business.contactInfo.facebook} type='email' />
            </InputGroup>
          </FormControl>
        </HStack>
        <HStack mt={2}>
          <FormControl pr={8}>
            <FormLabel>Twitter</FormLabel>
            <InputGroup>
              <InputLeftElement
                pointerEvents="none"
                children={<FaTwitter color="gray.300" />}
              />
              <Input isDisabled={true} value={business.contactInfo.twitter} type='email' />
            </InputGroup>
          </FormControl>
          <FormControl pl={8}>
            <FormLabel>LinkedIn</FormLabel>
            <InputGroup>
              <InputLeftElement
                pointerEvents="none"
                children={<FaLinkedinIn color="gray.300" />}
              />
              <Input isDisabled={true} value={business.contactInfo.linkedIn} type='email' />
            </InputGroup>
          </FormControl>
        </HStack>

        {business.status === 'missingImages' && (
          <Box
            align='center'
            justifyContent='space-evenly'
          >
            <Button
              bgGradient="linear(to-r, red.500, yellow.500)"
              color="white"
              _hover={{
                bgGradient: "linear(to-l, #7928CA,#FF0080)",
              }}
              width='full'
              mt={4}
              w={200}
              onClick={handleClick}
            >
              Afegir Imatges
            </Button>
          </Box>
        )}

        {business.status === 'finished' && (
          <Box
            align='left'
            justifyContent='space-evenly'
            mt={8}
          >
            <Heading as="h3" size="lg" mb={4}>
              Imatges
            </Heading>
            <AwesomeSlider
              media={businessImages}
            />
          </Box>
        )}
      </Box>
    </div >
  );
}

export default BusinessDetails;