const mongoose = require('mongoose');
const { toJSON, paginate } = require('./plugins');

const businessSchema = mongoose.Schema({
  name: {
    type: String,
    required: true,
  },
  description: {
    type: String,
    required: true,
  },
  address: {
    street: String,
    city: String,
    country: String,
    postalCode: String,
    province: String,
    location: {
      type: { type: String, default: 'Point' },
      coordinates: { type: [Number], default: [0, 0] }
    },
    placeId: String,
  },
  contactInfo: {
    phone: String,
    email: String,
    twitter: String,
    facebook: String,
    linkedIn: String,
    instagram: String,
  },
  description: String,
  timeTable: {
    from: String,
    to: String,
    days: [{
      type: String,
      enum: ['monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday']
    }]
  },
  user: {
    type: mongoose.Schema.Types.ObjectId,
    ref: "User"
  },
  rating: Number,
  images: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'BusinessImages',
  },
  categories: [
    {
      type: mongoose.Schema.Types.ObjectId,
      ref: 'Category'
    }
  ],
  status: { type: String, default: 'missingImages' },
  approved: { type: Boolean, default: false },
},
  {
    timestamps: true
  });

businessSchema.plugin(toJSON);
businessSchema.plugin(paginate);

const Business = mongoose.model('Business', businessSchema);

module.exports = Business;
