const express = require('express');
const auth = require('../../middlewares/auth');
const validate = require('../../middlewares/validate');
const businessValidation = require('../../validations/business.validation');
const businessController = require('../../controllers/business.controller');
const Multer = require('multer')
const upload = Multer({
  storage: Multer.memoryStorage(),
  limits: {
    fileSize: 10 * 1024 * 1024, // no larger than 5mb, you can change as needed.
  },
});

const router = express.Router();

router
  .route('/')
  .post(auth(), validate(businessValidation.createBusiness), businessController.createBusiness)
  .get(validate(businessValidation.getBusinesses), businessController.getBusinesses);
router
.route('/distance')
.post(businessController.businessDistance);

router
  .route('/:businessId')
  .get(validate(businessValidation.getBusiness), businessController.getBusiness)
  .patch(auth(), validate(businessValidation.updateBusiness), businessController.updateBusiness)
  .delete(auth(), validate(businessValidation.deleteBusiness), businessController.deleteBusiness);

router
  .route('/:businessId/images')
  .post(auth(), upload.array('file', 10), businessController.uploadImages);

router
  .route('/user/:userId')
  .get(auth(), validate(businessValidation.getBussinessByUserId), businessController.getBussinessByUserId);

module.exports = router;
