const httpStatus = require('http-status');
const { Business, BusinessImages, User } = require('../models');
const ApiError = require('../utils/ApiError');

const createBusiness = async (businessBody) => {
  const business = await Business.create(businessBody);
  const user = await User.findById(business.user);
  Object.assign(user, { business: business.id });
  await user.save();
  return business;
};


const queryBusiness = async (filter, options) => {
  return Business.find({ approved: true }).populate('categories').populate('images');
};

const getBusinessById = async (id) => {
  return Business.findById(id).populate('user').populate('categories').populate('images');
};

const getBussinessByUserId = async (userId) => {
  return Business.findOne({ user: userId }).populate('user').populate('categories').populate('images');
}

const updateBusinessById = async (businessId, updateBody) => {
  const business = await getBusinessById(businessId);
  if (!business) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Business not found');
  }

  Object.assign(business, updateBody);
  await business.save();
  return business;
};

const deleteBusinessById = async (businessId) => {
  const business = await getBusinessById(businessId);
  if (!business) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Business not found');
  }
  await business.remove();
  return business;
};

const createBusinessImages = async ({ businessId, gallery }) => {
  const business = await getBusinessById(businessId);
  const images = await BusinessImages.create({ businessId, gallery });
  Object.assign(business, { images: images.id, status: 'finished' });
  await business.save();
  return business;
}

module.exports = {
  createBusiness,
  queryBusiness,
  getBusinessById,
  updateBusinessById,
  deleteBusinessById,
  createBusinessImages,
  getBussinessByUserId,
};
