const caCountryList = require('./countries');
const fetch = require("node-fetch");
const { Client } = require('@googlemaps/google-maps-services-js');
const { response } = require('express');

const geolocatePlace = async (placeId) => {
  const client = new Client({});
  const apiKey = process.env.GOOGLE_MAPS_API_KEY;

  const response = await client.geocode({ params: { place_id: placeId, key: apiKey }, timeout: 3000 }); //fetch(`https://maps.googleapis.com/maps/api/geocode/json?place_id=${placeId}&key=${apiKey}`);
  const address_components = response.data.results[0].address_components;
  const street = address_components.find(el => el.types[0] === 'route');
  const number = address_components.find(el => el.types[0] === 'street_number');
  const city = address_components.find(el => el.types[0] === 'locality');
  const province = address_components.find(el => el.types[0] === 'administrative_area_level_2');
  const country = address_components.find(el => el.types[0] === 'country');
  const postalCode = address_components.find(el => el.types[0] === 'postal_code');
  const { geometry: { location } } = response.data.results[0];
  const countryName = caCountryList.find(el => el.iso2 === country.short_name);

  return {
    street: `${street.long_name}, ${number.long_name}`,
    city: city.long_name,
    country: countryName.nom,
    postalCode: postalCode.long_name,
    province: province.long_name,
    placeId,
    location: {
      type: 'Point',
      coordinates: [location.lng, location.lat]
    }
  }
};

const businessRating = async (placeId) => {
  const client = new Client({});
  const apiKey = process.env.GOOGLE_MAPS_API_KEY;
  const { data: { result } } = await client.placeDetails({ params: { place_id: placeId, key: apiKey } }); //fetch(`https://maps.googleapis.com/maps/api/geocode/json?place_id=${placeId}&key=${apiKey}`);
  return result.rating;
}

const distanceMatrix = async ({ bLat, bLng, lat, lng }) => {
  const client = new Client({});
  const apiKey = process.env.GOOGLE_MAPS_API_KEY;

  const { data } = await client.distancematrix({
    params: {
      origins: [{ lat: bLat, lng: bLng }],
      destinations: [{ lat, lng }],
      key: apiKey,
    }
  });
  if (data.status === 'OK') {
    return data.rows[0].elements[0].distance;
  }
  return null;
}

module.exports = {
  geolocatePlace,
  distanceMatrix,
  businessRating,
}