const Joi = require('joi');
const { objectId } = require('./custom.validation');

const createBusiness = {
  body: Joi.object().keys({
    name: Joi.string().required(),
    description: Joi.string().required(),
    place_id: Joi.string().required(),
    contactInfo: Joi.object().keys({
      phone: Joi.string().required(),
      email: Joi.string().email().required(),
      twitter: Joi.string().uri(),
      facebook: Joi.string().uri(),
      linkedIn: Joi.string().uri(),
      instagram: Joi.string().uri(),
    }),
    timeTable: Joi.object().keys({
      from: Joi.string().required(),
      to: Joi.string().required(),
      days: Joi.array().items(Joi.string().valid('monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday')),
    }),
    categories: Joi.array().items(Joi.string().custom(objectId))
  }),
};

const getBusinesses = {
  query: Joi.object().keys({
    name: Joi.string(),
    sortBy: Joi.string(),
    limit: Joi.number().integer(),
    page: Joi.number().integer(),
  }),
};

const getBusiness = {
  params: Joi.object().keys({
    businessId: Joi.string().custom(objectId),
  }),
};

const getBussinessByUserId = {
  params: Joi.object().keys({
    userId: Joi.string().custom(objectId),
  }),
};


const updateBusiness = {
  params: Joi.object().keys({
    businessId: Joi.string().custom(objectId),
  }),
  body: Joi.object()
    .keys({
      name: Joi.string(),
      description: Joi.string(),
    })
    .min(1),
};

const deleteBusiness = {
  params: Joi.object().keys({
    businessId: Joi.required().custom(objectId),
  }),
};

module.exports = {
  createBusiness,
  getBusiness,
  getBusinesses,
  updateBusiness,
  deleteBusiness,
  getBussinessByUserId,
}
